==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/AzureBlobFSLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.AzureBlobFSLocationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The location of azure blobFS dataset.
 * @property fileName Specify the file name of dataset. Type: string (or Expression with resultType string).
 * @property fileSystem Specify the fileSystem of azure blobFS. Type: string (or Expression with resultType string).
 * @property folderPath Specify the folder path of dataset. Type: string (or Expression with resultType string)
 * @property type Type of dataset storage location.
 * Expected value is 'AzureBlobFSLocation'.
 */
public data class AzureBlobFSLocationArgs(
    public val fileName: Output<Any>? = null,
    public val fileSystem: Output<Any>? = null,
    public val folderPath: Output<Any>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.AzureBlobFSLocationArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.AzureBlobFSLocationArgs =
        com.pulumi.azurenative.datafactory.inputs.AzureBlobFSLocationArgs.builder()
            .fileName(fileName?.applyValue({ args0 -> args0 }))
            .fileSystem(fileSystem?.applyValue({ args0 -> args0 }))
            .folderPath(folderPath?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureBlobFSLocationArgs].
 */
@PulumiTagMarker
public class AzureBlobFSLocationArgsBuilder internal constructor() {
    private var fileName: Output<Any>? = null

    private var fileSystem: Output<Any>? = null

    private var folderPath: Output<Any>? = null

    private var type: Output<String>? = null

    /**
     * @param value Specify the file name of dataset. Type: string (or Expression with resultType string).
     */
    @JvmName("knmwaevtpntdygud")
    public suspend fun fileName(`value`: Output<Any>) {
        this.fileName = value
    }

    /**
     * @param value Specify the fileSystem of azure blobFS. Type: string (or Expression with resultType string).
     */
    @JvmName("ylfshmlohuwehkia")
    public suspend fun fileSystem(`value`: Output<Any>) {
        this.fileSystem = value
    }

    /**
     * @param value Specify the folder path of dataset. Type: string (or Expression with resultType string)
     */
    @JvmName("qkhknstwotqjpwnr")
    public suspend fun folderPath(`value`: Output<Any>) {
        this.folderPath = value
    }

    /**
     * @param value Type of dataset storage location.
     * Expected value is 'AzureBlobFSLocation'.
     */
    @JvmName("cncedshcsofsievl")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specify the file name of dataset. Type: string (or Expression with resultType string).
     */
    @JvmName("ljwsaaxkjhafpbjo")
    public suspend fun fileName(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileName = mapped
    }

    /**
     * @param value Specify the fileSystem of azure blobFS. Type: string (or Expression with resultType string).
     */
    @JvmName("orqeouoadmkixdnt")
    public suspend fun fileSystem(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileSystem = mapped
    }

    /**
     * @param value Specify the folder path of dataset. Type: string (or Expression with resultType string)
     */
    @JvmName("hgudtnrmdcfnaerl")
    public suspend fun folderPath(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.folderPath = mapped
    }

    /**
     * @param value Type of dataset storage location.
     * Expected value is 'AzureBlobFSLocation'.
     */
    @JvmName("cmsyvksegjfinlld")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): AzureBlobFSLocationArgs = AzureBlobFSLocationArgs(
        fileName = fileName,
        fileSystem = fileSystem,
        folderPath = folderPath,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/AzureBlobFSLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.AzureBlobFSLocationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The location of azure blobFS dataset.
 * @property fileName Specify the file name of dataset. Type: string (or Expression with resultType string).
 * @property fileSystem Specify the fileSystem of azure blobFS. Type: string (or Expression with resultType string).
 * @property folderPath Specify the folder path of dataset. Type: string (or Expression with resultType string)
 * @property type Type of dataset storage location.
 * Expected value is 'AzureBlobFSLocation'.
 */
public data class AzureBlobFSLocationArgs(
    public val fileName: Output<Any>? = null,
    public val fileSystem: Output<Any>? = null,
    public val folderPath: Output<Any>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.AzureBlobFSLocationArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.AzureBlobFSLocationArgs =
        com.pulumi.azurenative.datafactory.inputs.AzureBlobFSLocationArgs.builder()
            .fileName(fileName?.applyValue({ args0 -> args0 }))
            .fileSystem(fileSystem?.applyValue({ args0 -> args0 }))
            .folderPath(folderPath?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureBlobFSLocationArgs].
 */
@PulumiTagMarker
public class AzureBlobFSLocationArgsBuilder internal constructor() {
    private var fileName: Output<Any>? = null

    private var fileSystem: Output<Any>? = null

    private var folderPath: Output<Any>? = null

    private var type: Output<String>? = null

    /**
     * @param value Specify the file name of dataset. Type: string (or Expression with resultType string).
     */
    @JvmName("ynlriqcqappbdcxl")
    public suspend fun fileName(`value`: Output<Any>) {
        this.fileName = value
    }

    /**
     * @param value Specify the fileSystem of azure blobFS. Type: string (or Expression with resultType string).
     */
    @JvmName("ysdsdsdonwamvkhm")
    public suspend fun fileSystem(`value`: Output<Any>) {
        this.fileSystem = value
    }

    /**
     * @param value Specify the folder path of dataset. Type: string (or Expression with resultType string)
     */
    @JvmName("dtidumravfhhlxcf")
    public suspend fun folderPath(`value`: Output<Any>) {
        this.folderPath = value
    }

    /**
     * @param value Type of dataset storage location.
     * Expected value is 'AzureBlobFSLocation'.
     */
    @JvmName("ldyqhndtkoipfjsq")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specify the file name of dataset. Type: string (or Expression with resultType string).
     */
    @JvmName("iyrkniffvbnkwrhe")
    public suspend fun fileName(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileName = mapped
    }

    /**
     * @param value Specify the fileSystem of azure blobFS. Type: string (or Expression with resultType string).
     */
    @JvmName("ngvkifyymjnpcmuf")
    public suspend fun fileSystem(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileSystem = mapped
    }

    /**
     * @param value Specify the folder path of dataset. Type: string (or Expression with resultType string)
     */
    @JvmName("vealvnwbnvlrbkdr")
    public suspend fun folderPath(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.folderPath = mapped
    }

    /**
     * @param value Type of dataset storage location.
     * Expected value is 'AzureBlobFSLocation'.
     */
    @JvmName("kmmqqvuemdrswpbg")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): AzureBlobFSLocationArgs = AzureBlobFSLocationArgs(
        fileName = fileName,
        fileSystem = fileSystem,
        folderPath = folderPath,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
